# zb
Personal established tools and implement of algorithm.


## Tools

* pdf2text

```python
from zb.tools import pdf2text

pdf_path = "test.pdf"
pdf_url = "http://www.cninfo.com.cn/cninfo-new/disclosure/szse/download/1205276701?announceTime=2018-08-11"
text = pdf2text(pdf_path)
```
